@@ -1,7 +1,8 @@
 import unittest
-import keras
 import numpy as np
 from keras_transformer import gelu, get_encoders
+from keras_bert.backend import keras
+from keras_bert.backend import backend as K
 from keras_bert.layers import get_inputs, get_embedding, Masked
 
 
@@ -17,7 +18,7 @@ class TestMasked(unittest.TestCase):
             loss='mse',
             metrics={},
         )
-        model.summary(line_length=120)
+        model.summary()
         model.predict([
             np.asarray([[1] + [0] * 511]),
             np.asarray([[0] * 512]),
@@ -65,9 +66,8 @@ class TestMasked(unittest.TestCase):
         model.compile(
             optimizer='adam',
             loss='mse',
-            metrics=['mse'],
         )
-        model.summary(line_length=150)
+        model.summary()
         predicts = model.predict([
             np.asarray([
                 [1, 2, 3, 4, 5, 6, 7, 8, 0, 0],
@@ -83,3 +83,29 @@ class TestMasked(unittest.TestCase):
             [0, 1, 0, 1, 0, 0, 0, 0, 0, 0],
         ])
         self.assertTrue(np.allclose(expect, predicts[1]))
+
+    def test_mask_loss(self):
+        def _loss(y_true, _):
+            return K.sum(y_true, axis=-1)
+
+        inputs = [keras.layers.Input((5,)), keras.layers.Input((5,))]
+        embed = keras.layers.Embedding(input_dim=2, output_dim=3, mask_zero=True)(inputs[0])
+        masked = Masked()([embed, inputs[1]])
+
+        model = keras.models.Model(inputs, masked)
+        model.compile(
+            optimizer='sgd',
+            loss=_loss,
+        )
+
+        token_input = np.array([
+            [1, 1, 1, 0, 0],
+            [1, 1, 1, 1, 0],
+        ])
+        mask_input = np.array([
+            [0, 1, 0, 0, 0],
+            [1, 0, 0, 0, 0],
+        ])
+        outputs = np.arange(30, dtype=K.floatx()).reshape((2, 5, 3))
+        actual = model.evaluate([token_input, mask_input], outputs)
+        self.assertTrue(np.abs(actual - 6.0) < 1e-6 or np.abs(actual - 30.0) < 1e-6, actual)
